# coding=utf-8
from distutils.core import setup

setup(name="bao_test",
      version="1.0",
      description="包的发送与接收",
      long_description="包的发送与接收的测试",
      author="dudu",
      author_email="931932073@qq.com",
      py_modules=["bao_test.receiv_message",
                  "bao_test.send_message"]
)
